<?php
/**
 * Mirasvit
 *
 * This source file is subject to the Mirasvit Software License, which is available at https://mirasvit.com/license/.
 * Do not edit or add to this file if you wish to upgrade the to newer versions in the future.
 * If you wish to customize this module for your needs.
 * Please refer to http://www.magentocommerce.com for more information.
 *
 * @category  Mirasvit
 * @package   mirasvit/module-email
 * @version   2.3.0
 * @copyright Copyright (C) 2022 Mirasvit (https://mirasvit.com/)
 */


declare(strict_types=1);


namespace Mirasvit\EmailDesigner\Ui\Theme\Form\Modifier;


use Magento\Framework\Stdlib\ArrayManager;
use Magento\Framework\View\Element\UiComponent\ContextInterface;
use Magento\Ui\DataProvider\Modifier\ModifierInterface;
use Mirasvit\EmailDesigner\Api\Data\ThemeInterface;
use Mirasvit\EmailDesigner\Repository\ThemeRepository;
use Mirasvit\EmailDesigner\Service\TemplateEngine\Liquid\VariableProvider;

class AreaModifier implements ModifierInterface
{
    private $themeRepository;

    private $arrayManager;

    private $context;

    private $variableProvider;

    public function __construct(
        VariableProvider $liquidVariableProvider,
        ThemeRepository $themeRepository,
        ArrayManager $arrayManager,
        ContextInterface $context
    ) {
        $this->themeRepository = $themeRepository;
        $this->arrayManager = $arrayManager;
        $this->context = $context;
        $this->variableProvider = $liquidVariableProvider;
    }

    /**
     * {@inheritdoc}
     */
    public function modifyData(array $data)
    {
        return $data;
    }

    /**
     * {@inheritdoc}
     */
    public function modifyMeta(array $meta)
    {
        $theme = $this->themeRepository->get((int)$this->context->getRequestParam(ThemeInterface::ID, null));

        $meta = $this->arrayManager->set(
            'general/children/editor',
            $meta,
            [
                'arguments' => [
                    'data' => [
                        'config' => [
                            'variables' => $this->getVariables()
                        ]
                    ]
                ],
                'children' => [
                    'areas' => [
                        'children' => $this->getAreaFields($theme ?: null)
                    ]
                ]
            ]
        );

        return $meta;
    }

    /**
     * Prepare area fields for theme.
     */
    private function getAreaFields(ThemeInterface $theme = null): array
    {
        return [
            ThemeInterface::TEMPLATE_TEXT => [
                'arguments' => [
                    'data' => [
                        'config' => [
                            'component' => 'Mirasvit_EmailDesigner/js/area',
                            'componentType' => 'textarea',
                            'dataType' => 'text',
                            'label' => 'Template Text',
                            'formElement' => 'textarea',
                            'source' => 'theme',
                            'dataScope' => ThemeInterface::TEMPLATE_TEXT,
                            'value' => $theme ? $theme->getTemplateText() : '',
                            'elementTmpl' => 'Mirasvit_EmailDesigner/editor/areas/area',
                        ]
                    ]
                ]
            ]
        ];
    }

    /**
     * Get theme variables.
     */
    private function getVariables(): array
    {
        $variables = $this->variableProvider->getVariables();
        $variables = array_merge([
            [
                'label' => (string)__('Theme Variables'),
                'value' => [
                    [
                        'label' => (string)__('Create Editable Area'),
                        'value' => "{{ 'area_name' | area: 'Default area text' }}"
                    ]
                ]
            ]
        ], $variables);

        return $variables;
    }
}
